@@ -41,9 +41,8 @@
 
 KSSH::KSSH(QWidget *parent, const char *name) : KSSHDialog(parent, name)
 {
-//opzioni estese!! corregere salva (XLE separato da -X). carica da zero
+//TODO
 
-//file selector
 
  QLayout *lay;
  lay=layout();
@@ -59,7 +58,7 @@ KSSH::KSSH(QWidget *parent, const char *name) : KSSHDialog(parent, name)
 
  editorF->hide();
 
-//mmmhhhh
+
 // show();
  QSize s=size();
 // warning("%d %d\n",s.width(),s.height());
@@ -92,10 +91,9 @@ compHost= new KCompletion();
 // compHost = hostCB->completionObject();
 hostCB->setCompletionObject(compHost);
 
- hostCB->setFocus();
-  hostCB->clearEdit();
-  hostCB->lineEdit()->installEventFilter( this );
- hostCB->setCompletionMode((KGlobalSettings::Completion)2);
+// hostCB->setFocus();
+//  hostCB->clearEdit();
+//  hostCB->lineEdit()->installEventFilter( this );
 
 
  // kdDebug(0) << compHost << endl;
@@ -128,6 +126,18 @@ connect(hostCB,SIGNAL(textChanged(const QString&)),this,SLOT(userFor(const QStri
  connect(savePB,SIGNAL(clicked()),this,SLOT(saveAsDefault()));
  connect(quitPB,SIGNAL(clicked()),qApp,SLOT(quit()));
 
+ config->setGroup("General");
+ hostCB->setCurrentText(config->readEntry("LastHost"));
+ int def=KGlobalSettings::completionMode();
+ config->setGroup("General");
+ int mode=config->readNumEntry("HostCompletionMode",def);
+// compHost->setCompletionMode((KGlobalSettings::Completion)mode);
+ hostCB->setCompletionMode((KGlobalSettings::Completion)mode);
+
+ config->setGroup("General");
+ mode=config->readNumEntry("UserCompletionMode",def);
+ //compUser->setCompletionMode((KGlobalSettings::Completion)mode);
+ userCB->setCompletionMode((KGlobalSettings::Completion)mode);
 
 }
 
@@ -198,12 +208,20 @@ void KSSH::about()
 void KSSH::ssh()
 {
 
+config->setGroup("General");
+ config->writeEntry("LastHost",hostCB->currentText());
+ config->writeEntry("HostCompletionMode",compHost->completionMode());
+ config->writeEntry("UserCompletionMode",compUser->completionMode());
+
+
  compUser->addItem(userCB->currentText());
  compHost->addItem(hostCB->currentText());
 
 if(saveCB->isChecked())
   saveOptions(hostCB->currentText()+"-Options");
 
+config->sync();
+
 // if(KCmdLineArgs::isSet("die") )
  KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
@@ -1330,7 +1348,10 @@ else
 
 void KSSH::hostEditor()
 {
- userHostELB->clear();
+// userHostELB->clear();
+
+userHostELB->listBox()->clear();
+userHostELB->lineEdit()->clear();
 
  uEditor=false;
  hEditor=true;
@@ -1343,7 +1364,10 @@ void KSSH::hostEditor()
 
 void KSSH::userEditor()
 {
- userHostELB->clear();
+// userHostELB->clear();
+
+userHostELB->listBox()->clear();
+userHostELB->lineEdit()->clear();
 
  uEditor=true;
  hEditor=false;
@@ -1357,7 +1381,7 @@ void KSSH::userEditor()
 void KSSH::okEditor()
 {
 
- if(uEditor)
+  if(uEditor)
  {
   userCB->clear();
   userCB->insertStringList(userHostELB->items());
@@ -1366,22 +1390,30 @@ void KSSH::okEditor()
  if(hEditor)
  {
   hostCB->clear();
-  hostCB->insertStringList(userHostELB->items());
-  compHost->setItems(userHostELB->items());
+  QStringList lista=userHostELB->items();
+ hostCB->insertStringList(lista);
+ compHost->setItems(lista);
  }
 
- saveLists();
- editorF->hide();
- userHostELB->clear();
+editorF->hide();
+
+userHostELB->listBox()->clear();
+userHostELB->lineEdit()->clear();
+
+
 
  uEditor=false;
  hEditor=false;
+ config->sync();
 }
 
 void KSSH::cancelEditor()
 {
  editorF->hide();
- userHostELB->clear();
+// userHostELB->clear();
+
+userHostELB->listBox()->clear();
+userHostELB->lineEdit()->clear();
 
  uEditor=false;
  hEditor=false;
